@@ -23,6 +23,7 @@ from dataclasses import dataclass, field, fields
 from functools import reduce
 import inspect
 from itertools import chain, product, repeat
+from math import ceil
 from multiprocessing.sharedctypes import RawArray
 from operator import mul
 import os
@@ -40,7 +41,7 @@ from .._ndvar import _concatenate_values, convolve_jit, parallel_convolve
 from .._utils import LazyProperty, PickleableDataClass, user_activity
 from .._utils.notebooks import tqdm
 from ._boosting_opt import l1, l2, generate_options, update_error
-from .shared import PredictorData, RevCorrData, Split, Splits, merge_segments
+from .shared import PredictorData, DeconvolutionData, Split, Splits, merge_segments
 from ._fit_metrics import get_evaluators
 
 
@@ -372,6 +373,21 @@ class BoostingResult(PickleableDataClass):
             name = self.y
         return NDVar(y_pred, dims, name, self._y_info)
 
+    def partition_result_data(self) -> Dataset:
+        """Results from the different test partitions in a :class:`Dataset`"""
+        h_is_list = isinstance(self._h, tuple)
+        rows = []
+        for res in self.partition_results:
+            hs = res.h if h_is_list else [res.h]
+            rows.append([res.i_test, res.r, res.proportion_explained, *hs])
+        if self.x in (None, (None,)):
+            xs = ['x']
+        elif isinstance(self.x, str):
+            xs = [self.x]
+        else:
+            xs = [f'x_{i}' if x is None else x for i, x in enumerate(self.x)]
+        return Dataset.from_caselist(['i_test', 'r', 'det', *xs], rows)
+
     @LazyProperty
     def proportion_explained(self):
         return 1 - (self.residual / self._variability)
@@ -483,7 +499,7 @@ class Boosting:
     Standard usage of the object-oriented API for a model with
     cross-validation, comparable to the :func:`boosting` function::
 
-        data = RevCorrData(y, x, ds)
+        data = DeconvolutionData(y, x, ds)
         data.apply_basis(0.05, 'hamming'')
         data.normalize('l1')
         data.initialize_cross_validation(5, test=1)
@@ -511,7 +527,7 @@ class Boosting:
 
     def __init__(
             self,
-            data: RevCorrData,
+            data: DeconvolutionData,
     ):
         self.data = data
 
@@ -554,7 +570,7 @@ class Boosting:
         # TRF extent in indices
         tstep = self.data.time.tstep
         i_start_by_x = np.asarray([int(round(t / tstep)) for t in tstart], np.int64)
-        i_stop_by_x = np.asarray([int(round(t / tstep)) for t in tstop], np.int64)
+        i_stop_by_x = np.asarray([int(ceil(t / tstep)) for t in tstop], np.int64)
         self._i_start = i_start = np.min(i_start_by_x)
         i_stop = np.max(i_stop_by_x)
         h_n_times = i_stop - i_start
@@ -870,6 +886,7 @@ def boosting(
         If data has cases, cases are divided with ``[::partitions]`` slices
         (default ``min(n_cases, 10)``; if ``model`` is specified, ``n_cases``
         is the lowest number of cases in any cell of the model).
+        See :ref:`exa-data_split` example.
     model
         If data has cases, divide cases into different categories (division
         for crossvalidation is done separately for each cell).
@@ -904,6 +921,10 @@ def boosting(
     result : BoostingResult
         Results (see :class:`BoostingResult`).
 
+    See Also
+    --------
+    plot.preview_partitions
+
     Notes
     -----
     In order to predict data, use the :func:`convolve` function::
@@ -916,6 +937,10 @@ def boosting(
 
     The boosting algorithm is described in [1]_.
 
+    See Also
+    --------
+    plot.preview_partitions : preview data partitions for cross-validation
+
     References
     ----------
     .. [1] David, S. V., Mesgarani, N., & Shamma, S. A. (2007). Estimating
@@ -938,7 +963,7 @@ def boosting(
     if selective_stopping < 0:
         raise ValueError(f"selective_stopping={selective_stopping}")
 
-    data = RevCorrData(y, x, ds, scale_in_place)
+    data = DeconvolutionData(y, x, ds, scale_in_place)
     data.apply_basis(basis, basis_window)
     if scale_data:
         data.normalize(error)
