@@ -5,14 +5,18 @@ from itertools import chain
 from typing import Any, Dict, Literal, Sequence, Union
 
 import numpy as np
-import matplotlib as mpl
+import matplotlib
+import matplotlib.axes
+import matplotlib.cm
 from matplotlib.colors import LinearSegmentedColormap, Colormap, Normalize, to_rgb
 from matplotlib.colorbar import ColorbarBase
+import matplotlib.patches
 from matplotlib.ticker import FixedFormatter, MaxNLocator
 
 from .._data_obj import CellArg, cellname
 from .._utils import IS_WINDOWS
-from ._base import EelFigure, Layout, AxisScale, CMapArg, ColorArg, fix_vlim_for_cmap
+from ._base import EelFigure, Layout, AxisScale, CMapArg, ColorArg, fix_vlim_for_cmap, inch_to_figure
+from ._styles import find_cell_styles
 
 
 POINT_SIZE = 0.0138889  # 1 point in inches
@@ -76,6 +80,12 @@ class ColorGrid(EelFigure):
             else:
                 raise KeyError(f"Neither {(row_cell_0, col_cell_0)} nor {(col_cell_0, row_cell_0)} exist as a key in colors")
 
+        if row_first:
+            cells = list(zip(row_cells, column_cells))
+        else:
+            cells = list(zip(column_cells, row_cells))
+        styles = find_cell_styles(cells, colors)
+
         # reverse rows so we can plot upwards
         row_cells = tuple(reversed(row_cells))
         n_rows = len(row_cells)
@@ -90,7 +100,7 @@ class ColorGrid(EelFigure):
             row_labels = row_cells
 
         # default size
-        chr_size = mpl.rcParams['font.size'] * POINT_SIZE
+        chr_size = matplotlib.rcParams['font.size'] * POINT_SIZE
         if size is None:
             size = chr_size * LEGEND_SIZE
         w_default = size * (n_cols + 1) + chr_size * max(len(l) for l in row_labels)
@@ -113,11 +123,11 @@ class ColorGrid(EelFigure):
                     cell = (column_cells[col], row_cells[row])
 
                 if shape == 'box':
-                    patch = mpl.patches.Rectangle((col, row), 1, 1, fc=colors[cell], ec='none')
+                    patch = matplotlib.patches.Rectangle((col, row), 1, 1, ec='none', **styles[cell].patch_args)
                     ax.add_patch(patch)
                 elif shape == 'line':
                     y = row + 0.5
-                    ax.plot([col, col + 1], [y, y], color=colors[cell])
+                    ax.plot([col, col + 1], [y, y], **styles[cell].line_args)
                 else:
                     raise ValueError(f"shape={shape!r}")
 
@@ -248,13 +258,14 @@ class ColorList(EelFigure):
             shape: str = 'box',
             **kwargs):
         if cells is None:
-            cells = tuple(colors.keys())
+            cells = colors.keys()
         elif isinstance(cells, Iterator):
             cells = tuple(cells)
+        styles = find_cell_styles(cells, colors)
 
         if h == 'auto':
             if size is None:
-                size = mpl.rcParams['font.size'] * LEGEND_SIZE * POINT_SIZE
+                size = matplotlib.rcParams['font.size'] * LEGEND_SIZE * POINT_SIZE
             h = len(cells) * size
         elif size is None:  # size = h / len(cells)
             pass
@@ -278,10 +289,10 @@ class ColorList(EelFigure):
             bottom = n - i - 1
             y = bottom + 0.5
             if shape == 'box':
-                patch = mpl.patches.Rectangle((0, bottom), 1, 1, fc=colors[cell], ec='none', zorder=1)
+                patch = matplotlib.patches.Rectangle((0, bottom), 1, 1, ec='none', **styles[cell].patch_args)
                 ax.add_patch(patch)
             elif shape == 'line':
-                ax.plot([0, 1], [y, y], color=colors[cell])
+                ax.plot([0, 1], [y, y], **styles[cell].line_args)
             else:
                 raise ValueError(f"shape={shape!r}")
             h = ax.text(1.1, y, labels.get(cell, cell), va='center', ha='left', zorder=2)
@@ -347,9 +358,12 @@ class ColorBar(EelFigure):
     width
         Width of the color-bar in inches.
     ticks
-        Customize tick-labels on the colormap; either a dictionary with
-        tick-locations and labels, or a sequence of tick locations. To draw no
-        ticks, set to ``()``.
+        Control tick-labels on the colormap. Can be:
+
+         - An integer number of evenly spaced ticks to draw
+         - A sequence of tick locations (``()`` to draw no ticks at all)
+         - A ``{float: str}`` dictionary with tick-locations and labels
+
     threshold
         Set the alpha of values below ``threshold`` to 0 (as well as for
         negative values above ``abs(threshold)``).
@@ -359,6 +373,13 @@ class ColorBar(EelFigure):
         Background color (for colormaps including transparency).
     ...
         Also accepts :ref:`general-layout-parameters`.
+    right_of
+        Plot the colorbar to the right of, and matching in height of the axes
+        specified in ``right_of``.
+    left_of
+        Plot the colorbar to the keft of, and matching in height of these axes.
+    below
+        Plot the colorbar below, and matching in width of these axes.
     """
     def __init__(
             self,
@@ -374,13 +395,17 @@ class ColorBar(EelFigure):
             unit: str = None,
             contours: Sequence[float] = (),
             width: float = None,
-            ticks: Union[Dict[float, str], Sequence[float]] = None,
+            ticks: Union[int, Dict[float, str], Sequence[float]] = None,
             threshold: float = None,
             ticklocation: Literal['auto', 'top', 'bottom', 'left', 'right'] = 'auto',
             background: ColorArg = 'white',
             tight: bool = True,
             h: float = None,
             w: float = None,
+            axes: matplotlib.axes.Axes = None,
+            right_of: matplotlib.axes.Axes = None,
+            left_of: matplotlib.axes.Axes = None,
+            below: matplotlib.axes.Axes = None,
             **kwargs,
     ):
         # get Colormap
@@ -389,14 +414,52 @@ class ColorBar(EelFigure):
                 raise NotImplementedError("threshold parameter with cmap=<array>")
             if cmap.max() > 1:
                 cmap = cmap / 255.
-            cm = mpl.colors.ListedColormap(cmap, 'LUT')
+            cm = matplotlib.colors.ListedColormap(cmap, 'LUT')
         elif isinstance(cmap, Colormap):
             cm = cmap
         else:
-            cm = mpl.cm.get_cmap(cmap)
+            cm = matplotlib.cm.get_cmap(cmap)
+
+        if any([right_of, left_of, below]):
+            if sum(map(bool, [axes, right_of, left_of, below])) != 1:
+                raise TypeError(f"{axes=}, {right_of=}, {left_of=}, {below=}: can only specify one at a time")
+            source_axes = right_of or left_of or below
+            figure = source_axes.get_figure()
+            source_bbox = source_axes.get_position()
+            if right_of or left_of:
+                thickness, _ = inch_to_figure(figure, x=width or 0.05)
+                y0 = source_bbox.y0
+                if h:
+                    _, height = inch_to_figure(figure, y=h)
+                    y0 += (source_bbox.bounds[3] - height) / 2
+                else:
+                    height = source_bbox.bounds[3]
+                if right_of:
+                    x0 = source_bbox.x1 + 2*thickness
+                else:
+                    x0 = source_bbox.x0 - 3*thickness
+                    if ticklocation == 'auto':
+                        ticklocation = 'left'
+                rect = (x0, y0, thickness, height)
+                orientation = 'vertical'
+            elif below:
+                _, thickness = inch_to_figure(figure, y=width or 0.05)
+                x0 = source_bbox.x0
+                if w:
+                    ax_width, _ = inch_to_figure(figure, x=w)
+                    x0 += (source_bbox.bounds[2] - ax_width) / 2
+                else:
+                    ax_width = source_bbox.bounds[2]
+                rect = (x0, source_bbox.y0 - 3*thickness, ax_width, thickness)
+                orientation = 'horizontal'
+            else:
+                raise RuntimeError
+            axes = figure.add_axes(rect)
 
         # prepare layout
-        if orientation == 'horizontal':
+        if axes:
+            ax_aspect = 1
+        elif orientation == 'horizontal':
             if h is None and w is None:
                 h = 1
             ax_aspect = 4
@@ -405,9 +468,9 @@ class ColorBar(EelFigure):
                 h = 4
             ax_aspect = 0.3
         else:
-            raise ValueError("orientation=%s" % repr(orientation))
+            raise ValueError(f"{orientation=}")
 
-        layout = Layout(1, ax_aspect, 2, tight, h=h, w=w, **kwargs)
+        layout = Layout(1, ax_aspect, 2, tight, h=h, w=w, axes=axes, **kwargs)
         EelFigure.__init__(self, cm.name, layout)
         ax = self.axes[0]
 
@@ -424,8 +487,13 @@ class ColorBar(EelFigure):
             scale = AxisScale(unit or 1, label)
 
         # value ticks
-        if ticks is False:
-            tick_locs = ()
+        if isinstance(ticks, int):
+            if ticks == 0:
+                tick_locs = ()
+            elif ticks == 1:
+                raise ValueError(f'{ticks=}')
+            else:
+                tick_locs = np.linspace(vmin, vmax, ticks)
             formatter = scale.formatter
         elif isinstance(ticks, dict):
             tick_locs = sorted(ticks)
