@@ -2,6 +2,7 @@
 """Plot topographic maps of sensor space data."""
 from __future__ import annotations
 
+import dataclasses
 from itertools import repeat
 from math import floor, sqrt
 from typing import Any, Dict, Literal, Sequence, Tuple, Union
@@ -25,68 +26,73 @@ from ._utsnd import _ax_butterfly, _ax_im_array, _plt_im
 from ._sensors import SENSORMAP_FRAME, SensorMapMixin, _plt_map2d
 
 
+InterpolationArg = Literal[None, 'nearest', 'linear', 'spline']
+SensorLabelsArg = Literal['', 'none', 'index', 'name', 'fullname']
+
+
 class Topomap(SensorMapMixin, ColorMapMixin, TopoMapKey, EelFigure):
     """Plot individual topogeraphies
 
     Parameters
     ----------
-    y : (list of) NDVar, dims = ([case,] sensor,)
+    y
         Data to plot.
-    xax : None | categorial
+    xax
         Create a separate plot for each cell in this model.
-    ds : Dataset
+    ds
         If a Dataset is provided, data can be specified as strings.
-    sub : str | array
+    sub
         Specify a subset of the data.
-    vmax : scalar
+    vmax
         Upper limits for the colormap (default is determined from data).
-    vmin : scalar
+    vmin
         Lower limit for the colormap (default ``-vmax``).
-    cmap : str
+    cmap
         Colormap (default depends on the data).
-    contours : int | sequence | dict
+    contours
         Contours to draw on topomaps. Can be an int (number of contours,
         including ``vmin``/``vmax``), a sequence (values at which to draw
         contours), or a ``**kwargs`` dict (must contain at least the "levels"
         key). Default is no contours.
-    proj : str | list of str
+    proj
         The sensor projection to use for topomaps (or one projection per plot).
-    res : int
+    res
         Resolution of the topomaps (width = height = ``res``).
-    interpolation : 'nearest' | 'linear' | 'spline'
+    interpolation
         Method for interpolating topo-map between sensors (default is based on
         mne-python).
     clip : bool | 'even' | 'circle'
         Outline for clipping topomaps: 'even' to clip at a constant distance
         (default), 'circle' to clip using a circle.
-    clip_distance : scalar
+    clip_distance
         How far from sensor locations to clip (1 is the axes height/width).
-    head_radius : scalar | tuple
+    head_radius
         Radius of the head outline drawn over sensors (on sensor plots with
         normalized positions, 0.45 is the outline of the topomap); 0 to plot no
         outline; tuple for separate (right, anterior) radius.
         The default is determined automatically.
-    head_pos : scalar
+    head_pos
         Head outline position along the anterior axis (0 is the center, 0.5 is
         the top end of the plot).
-    im_interpolation : str
+    im_interpolation
         Topomap image interpolation (see Matplotlib's
         :meth:`~matplotlib.axes.Axes.imshow`). Matplotlib 1.5.3's SVG output
         can't handle uneven aspect with ``interpolation='none'``, use
         ``interpolation='nearest'`` instead.
-    sensorlabels : 'none' | 'index' | 'name' | 'fullname'
+    sensorlabels
         Show sensor labels. For 'name', any prefix common to all names
         is removed; with 'fullname', the full name is shown.
-    mark : Sensor index
+    mark
         Sensors which to mark.
     mcolor : matplotlib color
         Color for marked sensors.
-    axtitle : bool | sequence of str
+    axtitle
         Title for the individual axes. The default is to show the names of the
         epochs, but only if multiple axes are plotted.
-    xlabel : str
-        Label below the topomaps (default is no label).
-    margins : dict
+    xlabel
+        Label below the topomaps (default is no label; ``True`` to use ``y``
+        names).
+    margins
         Layout parameter.
     ...
         Also accepts :ref:`general-layout-parameters`.
@@ -98,17 +104,35 @@ class Topomap(SensorMapMixin, ColorMapMixin, TopoMapKey, EelFigure):
      - ``T``: open a larger ``Topomap`` plot with visible sensor names for the
        map under the mouse pointer.
     """
-    def __init__(self, y, xax=None, ds=None, sub=None,
-                 vmax=None, vmin=None, cmap=None, contours=None,
-                 # topomap args
-                 proj='default', res=None, interpolation=None, clip='even',
-                 clip_distance=0.05, head_radius=None, head_pos=0,
-                 im_interpolation=None,
-                 # sensor-map args
-                 sensorlabels=None, mark=None, mcolor=None,
-                 # layout
-                 axtitle=True, xlabel=None, margins=None,
-                 **kwargs):
+    def __init__(
+            self,
+            y: Union[NDVarArg, Sequence[NDVarArg]],
+            xax: CategorialArg = None,
+            ds: Dataset = None,
+            sub: IndexArg = None,
+            vmax: float = None,
+            vmin: float = None,
+            cmap: CMapArg = None,
+            contours: Union[int, Sequence, Dict] = None,
+            # topomap args
+            proj: str = 'default',
+            res: int = None,
+            interpolation: InterpolationArg = None,
+            clip: Union[bool, str] = 'even',
+            clip_distance: float = 0.05,
+            head_radius: Union[float, Tuple[float, float]] = None,
+            head_pos: float = 0,
+            im_interpolation: str = None,
+            # sensor-map args
+            sensorlabels: SensorLabelsArg = None,
+            mark: IndexArg = None,
+            mcolor: ColorArg = None,
+            # layout
+            axtitle: Union[bool, Sequence[str]] = True,
+            xlabel: Union[bool, str] = None,
+            margins: Dict[str, float] = None,
+            **kwargs,
+    ):
         data = PlotData.from_args(y, ('sensor',), xax, ds, sub)
         self.plots = []
         ColorMapMixin.__init__(self, data.data, cmap, vmax, vmin, contours, self.plots)
@@ -126,10 +150,7 @@ class Topomap(SensorMapMixin, ColorMapMixin, TopoMapKey, EelFigure):
         # plots
         axes_data = data.for_plot(PlotType.IMAGE)
         for ax, layers, proj_ in zip(self.axes, axes_data, proj):
-            h = _ax_topomap(ax, layers, clip, clip_distance, sensorlabels, mark,
-                            mcolor, None, proj_, res, im_interpolation, xlabel,
-                            self._vlims, self._cmaps, self._contours, interpolation,
-                            head_radius, head_pos)
+            h = _ax_topomap(ax, layers, clip, clip_distance, sensorlabels, mark, mcolor, None, proj_, res, im_interpolation, xlabel, self._vlims, self._cmaps, self._contours, interpolation, head_radius, head_pos)
             self.plots.append(h)
 
         TopoMapKey.__init__(self, self._topo_data)
@@ -152,51 +173,57 @@ class TopomapBins(SensorMapMixin, ColorMapMixin, TopoMapKey, EelFigure):
 
     Parameters
     ----------
-    y : (list of) NDVar, dims = ([case,] sensor, time)
+    y
         Data to plot.
-    xax : None | categorial
+    xax
         Create a separate plot for each cell in this model.
-    ds : Dataset
+    ds
         If a Dataset is provided, data can be specified as strings.
-    sub : str | array
+    sub
         Specify a subset of the data.
-    vmax : scalar
+    bin_length
+        Length ofthe time bins for topo-plots.
+    tstart
+        Beginning of the first time bin (default is the beginning of ``y``).
+    tstop
+        End of the last time bin (default is the end of ``y``).
+    vmax
         Upper limits for the colormap (default is determined from data).
-    vmin : scalar
+    vmin
         Lower limit for the colormap (default ``-vmax``).
-    cmap : str
+    cmap
         Colormap (default depends on the data).
-    contours : int | sequence | dict
+    contours
         Contours to draw on topomaps. Can be an int (number of contours,
         including ``vmin``/``vmax``), a sequence (values at which to draw
         contours), or a ``**kwargs`` dict (must contain at least the "levels"
         key). Default is no contours.
-    proj : str
+    proj
         The sensor projection to use for topomaps.
-    res : int
+    res
         Resolution of the topomaps (width = height = ``res``).
-    interpolation : 'nearest' | 'linear' | 'spline'
+    interpolation
         Method for interpolating topo-map between sensors (default is based on
         mne-python).
     clip : bool | 'even' | 'circle'
         Outline for clipping topomaps: 'even' to clip at a constant distance
         (default), 'circle' to clip using a circle.
-    clip_distance : scalar
+    clip_distance
         How far from sensor locations to clip (1 is the axes height/width).
-    head_radius : scalar | tuple
+    head_radius
         Radius of the head outline drawn over sensors (on sensor plots with
         normalized positions, 0.45 is the outline of the topomap); 0 to plot no
         outline; tuple for separate (right, anterior) radius.
         The default is determined automatically.
-    head_pos : scalar
+    head_pos
         Head outline position along the anterior axis (0 is the center, 0.5 is
         the top end of the plot).
-    im_interpolation : str
+    im_interpolation
         Topomap image interpolation (see Matplotlib's
         :meth:`~matplotlib.axes.Axes.imshow`). Matplotlib 1.5.3's SVG output
         can't handle uneven aspect with ``interpolation='none'``, use
         ``interpolation='nearest'`` instead.
-    sensorlabels : 'none' | 'index' | 'name' | 'fullname'
+    sensorlabels
         Show sensor labels. For 'name', any prefix common to all names
         is removed; with 'fullname', the full name is shown.
     mark : Sensor index
@@ -213,16 +240,34 @@ class TopomapBins(SensorMapMixin, ColorMapMixin, TopoMapKey, EelFigure):
      - ``T``: open a larger ``Topomap`` plot with visible sensor names for the
        map under the mouse pointer.
     """
-    def __init__(self, y, xax=None, ds=None, sub=None,
-                 bin_length=0.05, tstart=None, tstop=None,
-                 vmax=None, vmin=None, cmap=None, contours=None,
-                 # topomap args
-                 proj='default', res=None, interpolation=None, clip='even',
-                 clip_distance=0.05, head_radius=None, head_pos=0,
-                 im_interpolation=None,
-                 # sensor-map args
-                 sensorlabels=None, mark=None, mcolor=None,
-                 **kwargs):
+    def __init__(
+            self,
+            y: Union[NDVarArg, Sequence[NDVarArg]],
+            xax: CategorialArg = None,
+            ds: Dataset = None,
+            sub: IndexArg = None,
+            bin_length: float = 0.050,
+            tstart: float = None,
+            tstop: float = None,
+            vmax: float = None,
+            vmin: float = None,
+            cmap: CMapArg = None,
+            contours: Union[int, Sequence, Dict] = None,
+            # topomap args
+            proj: str = 'default',
+            res: int = None,
+            interpolation: InterpolationArg = None,
+            clip: Union[bool, str] = 'even',
+            clip_distance: float = 0.05,
+            head_radius: Union[float, Tuple[float, float]] = None,
+            head_pos: float = 0,
+            im_interpolation: str = None,
+            # sensor-map args
+            sensorlabels: SensorLabelsArg = None,
+            mark: IndexArg = None,
+            mcolor: ColorArg = None,
+            **kwargs,
+    ):
         data = PlotData.from_args(y, ('sensor', 'time'), xax, ds, sub)
         self._plots = []
         data._cannot_skip_axes(self)
@@ -294,7 +339,7 @@ class TopoButterfly(ColorMapMixin, TimeSlicerEF, TopoMapKey, YLimMixin, XAxisMix
         The sensor projection to use for topomaps.
     res : int
         Resolution of the topomaps (width = height = ``res``).
-    interpolation : 'nearest' | 'linear' | 'spline'
+    interpolation
         Method for interpolating topo-map between sensors (default is based on
         mne-python).
     clip : bool | 'even' | 'circle'
@@ -315,7 +360,7 @@ class TopoButterfly(ColorMapMixin, TimeSlicerEF, TopoMapKey, YLimMixin, XAxisMix
         :meth:`~matplotlib.axes.Axes.imshow`). Matplotlib 1.5.3's SVG output
         can't handle uneven aspect with ``interpolation='none'``, use
         ``interpolation='nearest'`` instead.
-    sensorlabels : 'none' | 'index' | 'name' | 'fullname'
+    sensorlabels
         Show sensor labels. For 'name', any prefix common to all names
         is removed; with 'fullname', the full name is shown.
     mark : Sensor index
@@ -387,20 +432,20 @@ class TopoButterfly(ColorMapMixin, TimeSlicerEF, TopoMapKey, YLimMixin, XAxisMix
             t: float = None,
             proj: str = 'default',
             res: int = None,
-            interpolation: str = None,
+            interpolation: InterpolationArg = None,
             clip: Union[bool, str] = 'even',
             clip_distance: float = 0.05,
             head_radius: Union[float, Tuple[float, float]] = None,
             head_pos: float = 0,
             im_interpolation: str = None,
             # sensor-map args
-            sensorlabels: str = None,
+            sensorlabels: SensorLabelsArg = None,
             mark: IndexArg = None,
             mcolor: ColorArg = None,
             # layout
             xlabel: Union[bool, str] = True,
             ylabel: Union[bool, str] = True,
-            xticklabels: Union[str, int, Sequence[int]] = -1,
+            xticklabels: Union[str, int, Sequence[int]] = 'bottom',
             yticklabels: Union[str, int, Sequence[int]] = 'left',
             axtitle: Union[bool, Sequence[str]] = True,
             frame: bool = True,
@@ -522,7 +567,7 @@ class _plt_topomap(_plt_im):
         Empty space beyond outmost sensors in the im plot.
     vmax : scalar
         Override the colorspace vmax.
-    interpolation : 'nearest' | 'linear' | 'spline'
+    interpolation
         Method for interpolating topo-map between sensors.
     """
     _aspect = 'equal'
@@ -537,7 +582,7 @@ class _plt_topomap(_plt_im):
             vlims,
             cmaps,
             contours,
-            interpolation: str,
+            interpolation: InterpolationArg,
             clip: str,
             clip_distance: float,
     ):
@@ -650,13 +695,13 @@ class _ax_topomap(_ax_im_array):
     """
     def __init__(
             self,
-            ax,
+            ax: matplotlib.axes.Axes,
             layers: AxisData,
             clip: str = 'even',  # even or circle (only applies if interpolation is None)
             clip_distance: float=0.05,  # distance from outermost sensor for clip=='even'
-            sensorlabels: Literal['', 'none', 'index', 'name', 'fullname'] = None,
-            mark=None,
-            mcolor=None,
+            sensorlabels: SensorLabelsArg = None,
+            mark: IndexArg = None,
+            mcolor: ColorArg = None,
             mmarker=None,
             proj: str = 'default',  # topomap projection method
             res: int = None,  # topomap image resolution
@@ -665,7 +710,7 @@ class _ax_topomap(_ax_im_array):
             vlims: dict = {},
             cmaps: dict = {},
             contours: dict = {},
-            interpolation: str = None,  # topomap interpolation method
+            interpolation: InterpolationArg = None,  # topomap interpolation method
             head_radius: float = None,
             head_pos: Union[float, Tuple[float, float]] = 0.,  # y if centered on x, or (x, y)
             head_linewidth: float = None,
@@ -704,30 +749,25 @@ class _ax_topomap(_ax_im_array):
         self.set_vlim(bottom, top)
 
 
+@dataclasses.dataclass
 class _TopoWindow:
     """Helper class for TopoArray.
 
     Maintains a topomap corresponding to one segment with flexible time point.
     """
+    ax: matplotlib.axes.Axes  # topomap-axes
+    parent: _ax_im_array  # array-plot
+    topomap_args: dict
+    connectionstyle: str = "angle3,angleA=90,angleB=0"
+    label_position: Literal['above', 'below', 'none'] = 'above'
+    color: ColorArg = UNAMBIGUOUS_COLORS['bluish green']
+    annotation_xy: Tuple[float, float] = (0.5, 1.05)
+    # internal plot handles
     t_line = None
     pointer = None
+    text_pointer = None
     plot = None
     t = None
-    _annotation_xy = (0.5, 1.05)
-
-    def __init__(
-            self,
-            ax: matplotlib.axes.Axes,  # topomap-axes
-            parent: _ax_im_array,  # array-plot
-            color: ColorArg = UNAMBIGUOUS_COLORS['bluish green'],
-            connectionstyle: str = "angle3,angleA=90,angleB=0",
-            **topomap_args,
-    ):
-        self.ax = ax
-        self.parent = parent
-        self.color = color
-        self.connectionstyle = connectionstyle
-        self.topomap_args = topomap_args
 
     def update(self, t):
         if t is not None:
@@ -739,13 +779,19 @@ class _TopoWindow:
             if self.pointer:
                 self.pointer.axes = self.parent.ax
                 self.pointer.xy = (t, 1)
-                self.pointer.set_text(t_str)
+                if self.text_pointer:
+                    self.text_pointer.set_text(t_str)
                 self.pointer.set_visible(True)
             else:
+                text = t_str if self.label_position == 'above' else ''
                 arrowprops = {'arrowstyle': '-', 'shrinkB': 0, 'color': self.color}
                 if self.connectionstyle:
                     arrowprops['connectionstyle'] = self.connectionstyle
-                self.pointer = self.parent.ax.annotate(t_str, (t, 0), xycoords='data', xytext=self._annotation_xy, textcoords=self.ax.transData, horizontalalignment='center', verticalalignment='center', arrowprops=arrowprops, zorder=4)
+                self.pointer = self.parent.ax.annotate(text, (t, 0), xycoords='data', xytext=self.annotation_xy, textcoords=self.ax.transData, horizontalalignment='center', verticalalignment='center', arrowprops=arrowprops, zorder=4)
+                if self.label_position == 'above':
+                    self.text_pointer = self.pointer
+                elif self.label_position == 'below':
+                    self.text_pointer = self.ax.text(0.5, 0, t_str, va='top', ha='center', transform=self.ax.transAxes)
 
             if self.plot is None:
                 layers = self.parent.data.sub_time(t)
@@ -815,7 +861,7 @@ class TopoArray(ColorMapMixin, TopoMapKey, XAxisMixin, EelFigure):
         The sensor projection to use for topomaps.
     res
         Resolution of the topomaps (width = height = ``res``).
-    interpolation : 'nearest' | 'linear' | 'spline'
+    interpolation
         Method for interpolating topo-map between sensors (default is based on
         mne-python).
     clip : bool | 'even' | 'circle'
@@ -863,6 +909,10 @@ class TopoArray(ColorMapMixin, TopoMapKey, XAxisMixin, EelFigure):
         Style for the connections between the image array-plot and the
         topo-maps. Set to ``''`` for straight connections. See
         `Matplotlib demo <https://matplotlib.org/stable/gallery/userdemo/connectionstyle_demo.html>`_.
+    connection_color
+        Color for connection line.
+    topo_labels
+        Where to label time on topo-maps.
     ...
         Also accepts :ref:`general-layout-parameters`.
 
@@ -891,68 +941,83 @@ class TopoArray(ColorMapMixin, TopoMapKey, XAxisMixin, EelFigure):
             # topomap args
             proj: str = 'default',
             res: int = None,
-            interpolation: str = None,
+            interpolation: InterpolationArg = None,
             clip: Union[bool, str] = 'even',
             clip_distance: float = 0.05,
             head_radius: Union[float, Tuple[float, float]] = None,
             head_pos: float = 0,
             im_interpolation: str = None,
             # sensor-map args
-            sensorlabels: Literal['', 'none', 'index', 'name', 'fullname'] = None,
+            sensorlabels: SensorLabelsArg = None,
             mark: IndexArg = None,
             mcolor: ColorArg = None,
             # layout
             axtitle: Union[bool, Sequence[str]] = True,
             xlabel: Union[bool, str] = True,
             ylabel: Union[bool, str] = True,
-            xticklabels: Union[int, Sequence[int]] = -1,
-            yticklabels: Union[int, Sequence[int]] = 0,
+            xticklabels: Union[str, int, Sequence[int]] = 'bottom',
+            yticklabels: Union[str, int, Sequence[int]] = 'left',
             connectionstyle: str = "angle3,angleA=90,angleB=0",
+            connection_color: ColorArg = UNAMBIGUOUS_COLORS['bluish green'],
+            topo_labels: Literal['above', 'below', 'none'] = 'above',
             **kwargs,
     ):
         if ntopo is None:
             ntopo = len(t) if t else 3
 
         data = PlotData.from_args(y, ('time', 'sensor'), xax, ds, sub).for_plot(PlotType.IMAGE)
-        n_topo_total = ntopo * data.n_plots
 
         # create figure
-        layout = Layout(data.plot_used, 1.5, 4, tight=False, **kwargs)
+        if 'ncol' not in kwargs and 'nrow' not in kwargs:
+            kwargs['nrow'] = 1
+        layout = Layout(data.plot_used, 1.5, 3, tight=False, **kwargs)
         EelFigure.__init__(self, data.frame_title, layout)
         all_plots = []
         ColorMapMixin.__init__(self, data.data, cmap, vmax, vmin, contours, all_plots)
         TopoMapKey.__init__(self, self._topo_data)
 
-        # fig coordinates
-        x_frame_l = .6 / self._layout.axw / data.n_plots
-        x_frame_r = .025 / data.n_plots
-        x_sep = .01 / data.n_plots
-        x_per_ax = (1 - x_frame_l - x_frame_r) / data.n_plots
-
-        self.figure.subplots_adjust(left=x_frame_l, right=1 - x_frame_r, bottom=.05, top=.9, wspace=.1, hspace=.3)
-
         # save important properties
         self._data = data
         self._ntopo = ntopo
         self._default_xlabel_ax = -1 - ntopo
         self._proj = proj
 
+        # prepare axes
+        if layout.user_axes:
+            self.axes = layout.user_axes
+        else:
+            x_frame_l = .6 / layout.axw / data.n_plots
+            x_frame_r = .025 / data.n_plots
+            gs = self.figure.add_gridspec(layout.nrow * 2, layout.ncol * ntopo, left=x_frame_l, right=1 - x_frame_r, bottom=.05, top=.9, wspace=.1, hspace=.3)
+            if layout.nrow == 1:
+                for col, used in enumerate(data.plot_used):
+                    if not used:
+                        continue
+                    self.figure.add_subplot(gs[0, col*ntopo:(col+1)*ntopo], picker=True)
+                    for j in range(ntopo):
+                        self.figure.add_subplot(gs[1, col*ntopo+j], picker=True, xticks=[], yticks=[])
+            elif layout.ncol == 1:
+                for row, used in enumerate(data.plot_used):
+                    if not used:
+                        continue
+                    self.figure.add_subplot(gs[row*2, 0:ntopo], picker=True)
+                    for j in range(ntopo):
+                        self.figure.add_subplot(gs[row*2+1, j], picker=True, xticks=[], yticks=[])
+            else:
+                raise ValueError("Layout with multiple columns and rows; set either ncol=1 or nrow=1")
+            self.axes = self.figure.axes
+
         # im_array plots
         self._array_axes = []
         self._array_plots = []
         self._topo_windows = []
-        ax_height = .4 + .07 * (not layout.title)
-        ax_bottom = .45  # + .05*(not title)
+        topomap_args = dict(clip=clip, clip_distance=clip_distance, sensorlabels=sensorlabels, mark=mark, mcolor=mcolor, proj=proj, res=res, im_interpolation=im_interpolation, vlims=self._vlims, cmaps=self._cmaps, contours=self._contours, interpolation=interpolation, head_radius=head_radius, head_pos=head_pos)
         for i, layers in enumerate(data):
-            ax_left = x_frame_l + i * (x_per_ax + x_sep)
-            ax_right = 1 - x_frame_r - (data.n_plots - i - 1) * (x_per_ax + x_sep)
-            ax_width = ax_right - ax_left
-            ax = self.figure.add_axes((ax_left, ax_bottom, ax_width, ax_height),
-                                      picker=True)
+            ax_i = i * (ntopo + 1)
+            ax = self.axes[ax_i]
             ax.ID = i
             ax.type = 'main'
             im_plot = _ax_im_array(ax, layers, 'time', im_interpolation, self._vlims, self._cmaps, self._contours)
-            self.axes.append(ax)
             self._array_axes.append(ax)
             self._array_plots.append(im_plot)
             if i > 0:
@@ -960,13 +1025,10 @@ class TopoArray(ColorMapMixin, TopoMapKey, XAxisMixin, EelFigure):
 
             # topo plots
             for j in range(ntopo):
-                ID = i * ntopo + j
-                ax = self.figure.add_subplot(3, n_topo_total,
-                                             2 * n_topo_total + 1 + ID,
-                                             picker=True, xticks=[], yticks=[])
-                ax.ID = ID
+                ax = self.axes[ax_i + 1 + j]
+                ax.ID = i * ntopo + j
                 ax.type = 'window'
-                win = _TopoWindow(ax, im_plot, connectionstyle=connectionstyle, clip=clip, clip_distance=clip_distance, sensorlabels=sensorlabels, mark=mark, mcolor=mcolor, proj=proj, res=res, im_interpolation=im_interpolation, vlims=self._vlims, cmaps=self._cmaps, contours=self._contours, interpolation=interpolation, head_radius=head_radius, head_pos=head_pos)
+                win = _TopoWindow(ax, im_plot, topomap_args, connectionstyle, topo_labels, connection_color)
                 self.axes.append(ax)
                 self._topo_windows.append(win)
         all_plots.extend(self._array_plots)
